<?php
/***************************************************************************
                                digest_tables.php
                             -------------------
    begin                : Thurs Apr 19, 2007
    copyright            : (c) Mark D. Hamill
    email                : mhamill@computer.org

    $Id: $

 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

// digest_tables.php
// Written by Mark D. Hamill, mhamill@computer.org
// This software is designed to work with phpBB Version 2.0.22

// This is a "run once" program that creates three tables needed for this modification. Make sure you have
// defined the names of the tables in the digest_functions.php include file. The include file needs to be 
// installed before this can be run.

// Modified 8/6/06 to work with MySQL as well as Postgres and MS SQL databases. 

define('IN_PHPBB', true);
$phpbb_root_path = '../';

include($phpbb_root_path . 'extension.inc');
include($phpbb_root_path . 'common.'.$phpEx);
include($phpbb_root_path . 'includes/digest_functions.' . $phpEx); 

switch ($dbms) 

{

	case 'mysql':
	case 'mysql4':

		// create subscriptions table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " (
			user_id INTEGER NOT NULL DEFAULT 0,
			digest_type CHAR(4) NOT NULL DEFAULT 'DAY',
			format CHAR(4) NOT NULL DEFAULT 'TEXT',
			show_text CHAR(3) NOT NULL DEFAULT 'YES',
			show_mine CHAR(3) NOT NULL DEFAULT 'YES',
			new_only CHAR(5) NOT NULL DEFAULT 'TRUE',
			send_on_no_messages CHAR(3) NOT NULL DEFAULT 'NO',
			send_hour SMALLINT NOT NULL DEFAULT 0,
			text_length INTEGER NOT NULL DEFAULT 0,
			show_pms CHAR(3) NOT NULL DEFAULT 'YES',
			CONSTRAINT " . DIGEST_SUBSCRIPTIONS_TABLE . '_pk PRIMARY KEY (user_id)
		)';

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create subscribed forums table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' (
			user_id MEDIUMINT(8) NOT NULL DEFAULT 0,
			forum_id SMALLINT(5) NOT NULL DEFAULT 0,
			UNIQUE user_id (user_id, forum_id)
			)';

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SUBSCRIBED_FORUMS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create the settings table
		$sql='CREATE TABLE ' . DIGEST_SETTINGS_TABLE . " (
		  table_key int(11) NOT NULL,
		  version varchar(10) NOT NULL default '1.0.17',
		  site_url varchar(255) NOT NULL default 'http://www.example.com/phpBB/',
		  autosubscribe_users char(3) NOT NULL default 'NO',
		  autosubscribe_daily varchar(4) NOT NULL default 'DAY',
		  weekly_digest_day int(11) NOT NULL default '0',
		  use_custom_stylesheet char(3) NOT NULL default 'NO',
		  custom_stylesheet_path varchar(255) NOT NULL default 'templates/subSilver/digest_stylesheet.css',
		  date_format varchar(20) NOT NULL default 'd M Y h:i A',
		  server_display_date varchar(20) NOT NULL default 'm/d/Y',
		  html_encoding varchar(20) NOT NULL default 'iso-8859-1',
		  text_encoding varchar(20) NOT NULL default 'us-ascii',
		  show_summary char(3) NOT NULL default 'YES',
		  summary_type varchar(4) NOT NULL default 'HTML',
		  require_send_key char(3) NOT NULL default 'NO',
		  send_key varchar(255) NOT NULL default 'qwertyuiop',
		  users_per_page int(11) NOT NULL default '20',
		  mail_digests_phpbb_path varchar(255) NOT NULL default './',
		  PRIMARY KEY  (table_key)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1 COMMENT='Digest Settings Table' AUTO_INCREMENT=1";

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}
		
		// Insert the one row required in the digest settings table
		$sql = 'INSERT INTO ' . DIGEST_SETTINGS_TABLE . ' (table_key) VALUES (1)'; 
		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to insert row into '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		break;

	case 'postgres':

		// create subscriptions table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " (
			user_id INTEGER NOT NULL DEFAULT 0,
			digest_type CHAR(4) NOT NULL DEFAULT 'DAY',
			format CHAR(4) NOT NULL DEFAULT 'TEXT',
			show_text CHAR(3) NOT NULL DEFAULT 'YES',
			show_mine CHAR(3) NOT NULL DEFAULT 'YES',
			new_only CHAR(5) NOT NULL DEFAULT 'TRUE',
			send_on_no_messages CHAR(3) NOT NULL DEFAULT 'NO',
			send_hour SMALLINT NOT NULL DEFAULT 0,
			text_length INTEGER NOT NULL DEFAULT 0,
			show_pms CHAR(3) NOT NULL DEFAULT 'YES',
			CONSTRAINT " . DIGEST_SUBSCRIPTIONS_TABLE . '_pk PRIMARY KEY (user_id))';

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create subscribed forums table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' (
			user_id INTEGER NOT NULL DEFAULT 0,
			forum_id SMALLINT NOT NULL DEFAULT 0)';


		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create the subscribed forums table index
		$sql='CREATE UNIQUE INDEX ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . 'us ON ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' (user_id, forum_id)';

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create index on '. DIGEST_SUBSCRIBED_FORUMS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		break;

		// create the settings table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " (
		  \"table_key\" int(11) NOT NULL,
		  \"version\" varchar(10) NOT NULL default '1.0.17',
		  \"site_url\" varchar(255) NOT NULL default 'http://www.example.com/phpBB/',
		  \"autosubscribe_users\" char(3) NOT NULL default 'NO',
		  \"autosubscribe_daily\" varchar(4) NOT NULL default 'DAY',
		  \"weekly_digest_day\" int(11) NOT NULL default '0',
		  \"use_custom_stylesheet\" char(3) NOT NULL default 'NO',
		  \"custom_stylesheet_path\" varchar(255) NOT NULL default 'templates/subSilver/digest_stylesheet.css',
		  \"date_format\" varchar(20) NOT NULL default 'd M Y h:i A',
		  \"server_display_date\" varchar(20) NOT NULL default 'm/d/Y',
		  \"html_encoding\" varchar(20) NOT NULL default 'iso-8859-1',
		  \"text_encoding\" varchar(20) NOT NULL default 'us-ascii',
		  \"show_summary\" char(3) NOT NULL default 'YES',
		  \"summary_type\" varchar(4) NOT NULL default 'HTML',
		  \"require_send_key\" char(3) NOT NULL default 'NO',
		  \"send_key\" varchar(255) NOT NULL default 'qwertyuiop',
		  \"users_per_page\" int(11) NOT NULL default '20',
		  \"mail_digests_phpbb_path\" varchar(255) NOT NULL default './',
		  PRIMARY KEY  (\"table_key\")
		) AUTO_INCREMENT=1";

		// Insert the one row required in the digest settings table
		$sql = 'INSERT INTO ' . DIGEST_SETTINGS_TABLE . ' (table_key) VALUES (1)'; 
		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to insert row into '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

	case 'mssql':

		// create subscriptions table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " (
			user_id INTEGER NOT NULL DEFAULT 0,
			digest_type CHAR(4) NOT NULL DEFAULT 'DAY',
			format CHAR(4) NOT NULL DEFAULT 'TEXT',
			show_text CHAR(3) NOT NULL DEFAULT 'YES',
			show_mine CHAR(3) NOT NULL DEFAULT 'YES',
			new_only CHAR(5) NOT NULL DEFAULT 'TRUE',
			send_on_no_messages CHAR(3) NOT NULL DEFAULT 'NO',
			send_hour SMALLINT NOT NULL DEFAULT 0,
			text_length INTEGER NOT NULL DEFAULT 0,
			show_pms CHAR(3) NOT NULL DEFAULT 'YES',
			CONSTRAINT " . DIGEST_SUBSCRIPTIONS_TABLE. '_pk PRIMARY KEY (user_id))';


		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create subscribed forums table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' (
			user_id INTEGER NOT NULL DEFAULT 0,
			forum_id SMALLINT NOT NULL DEFAULT 0
		)  ON [PRIMARY]';


		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		// create the subscribed forums table index
		$sql='CREATE UNIQUE INDEX ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . 'us ON ' . DIGEST_SUBSCRIBED_FORUMS_TABLE . ' (user_id, forum_id) ON [PRIMARY]';

		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to create index on '. DIGEST_SUBSCRIBED_FORUMS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

		break;

		// create the settings table
		$sql='CREATE TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " (
		  \"table_key\" int(11) NOT NULL,
		  \"version\" varchar(10) NOT NULL default '1.0.17',
		  \"site_url\" varchar(255) NOT NULL default 'http://www.example.com/phpBB/',
		  \"autosubscribe_users\" char(3) NOT NULL default 'NO',
		  \"autosubscribe_daily\" varchar(4) NOT NULL default 'DAY',
		  \"weekly_digest_day\" int(11) NOT NULL default '0',
		  \"use_custom_stylesheet\" char(3) NOT NULL default 'NO',
		  \"custom_stylesheet_path\" varchar(255) NOT NULL default 'templates/subSilver/digest_stylesheet.css',
		  \"date_format\" varchar(20) NOT NULL default 'd M Y h:i A',
		  \"server_display_date\" varchar(20) NOT NULL default 'm/d/Y',
		  \"html_encoding\" varchar(20) NOT NULL default 'iso-8859-1',
		  \"text_encoding\" varchar(20) NOT NULL default 'us-ascii',
		  \"show_summary\" char(3) NOT NULL default 'YES',
		  \"summary_type\" varchar(4) NOT NULL default 'HTML',
		  \"require_send_key\" char(3) NOT NULL default 'NO',
		  \"send_key\" varchar(255) NOT NULL default 'qwertyuiop',
		  \"users_per_page\" int(11) NOT NULL default '20',
		  \"mail_digests_phpbb_path\" varchar(255) NOT NULL default './',
		  PRIMARY KEY  (\"table_key\")
		) AUTO_INCREMENT=1";

		// Insert the one row required in the digest settings table
		$sql = 'INSERT INTO ' . DIGEST_SETTINGS_TABLE . ' (table_key) VALUES (1)'; 
		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Unable to insert row into '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}

	default:

		message_die(GENERAL_ERROR, 'Only MySQL, Postgres and MS SQL digest tables can be created with this script.', '', __LINE__, __FILE__, $sql);

}
		
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Digest Mod Table Installation</title>
<link rel="stylesheet" href="../templates/subSilver/subSilver.css" type="text/css">
<style type="text/css">
<!--
th			{ background-image: url('../templates/subSilver/images/cellpic3.gif') }
td.cat		{ background-image: url('../templates/subSilver/images/cellpic1.gif') }
td.rowpic	{ background-image: url('../templates/subSilver/images/cellpic2.jpg'); background-repeat: repeat-y }
td.catHead,td.catSides,td.catLeft,td.catRight,td.catBottom { background-image: url('../templates/subSilver/images/cellpic1.gif') }

/* Import the fancy styles for IE only (NS4.x doesn't use the @import function) */
@import url("../templates/subSilver/formIE.css"); 
//-->
</style>
</head>
<body bgcolor="#E5E5E5" text="#000000" link="#006699" vlink="#5584AA"> 
<p>If you see this message, then all digest database tables and indexes were successfully created!</p> 
<p>Please delete this file and remove the install directory, since your forum will not be accessible until it is removed.</p> 
</body>
</html>
